@@ -22,8 +22,9 @@ case $directory in
   hello-c++-kde)
     ./autogen.sh
     sed -e 's,tmp-,,' < configure.in > configure.ac
-    grep '^\(AC_INIT\|AC_CONFIG\|AC_PROG_\|AC_SUBST(.*OBJC\|AM_INIT\|AM_CONDITIONAL\|AM_GNU_GETTEXT\|AM_PO_SUBDIRS\|AC_OUTPUT\)' configure.ac > configure.in
-    rm -f configure.ac 
+    rm -f configure.in
+    grep '^\(AC_INIT\|AC_CONFIG\|AC_PROG_\|AC_SUBST(.*OBJC\|AM_INIT\|AM_CONDITIONAL\|AM_GNU_GETTEXT\|AM_PO_SUBDIRS\|AC_OUTPUT\)' configure.ac > tmp-configure.ac
+    mv -f tmp-configure.ac configure.ac
     autoconf -f
     ./configure
     ;;
@@ -31,8 +32,8 @@ case $directory in
     ./autogen.sh
     ;;
   *)
-    grep '^\(AC_INIT\|AC_CONFIG\|AC_PROG_\|AC_SUBST(.*OBJC\|AM_INIT\|AM_CONDITIONAL\|AM_GNU_GETTEXT\|AM_PO_SUBDIRS\|AC_OUTPUT\)' configure.ac > configure.in
-    rm -f configure.ac 
+    grep '^\(AC_INIT\|AC_CONFIG\|AC_PROG_\|AC_SUBST(.*OBJC\|AM_INIT\|AM_CONDITIONAL\|AM_GNU_GETTEXT\|AM_PO_SUBDIRS\|AC_OUTPUT\)' configure.ac > tmp-configure.ac
+    mv -f tmp-configure.ac configure.ac
     ./autogen.sh
     ./configure
     ;;
