@@ -1,11 +1,11 @@
 /* Manipulates attributes of messages in translation catalogs.
-   Copyright (C) 2001-2006 Free Software Foundation, Inc.
+   Copyright (C) 2001-2007, 2009-2010, 2012 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2001.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 
 #ifdef HAVE_CONFIG_H
@@ -43,8 +42,9 @@
 #include "write-po.h"
 #include "write-properties.h"
 #include "write-stringtable.h"
-#include "exit.h"
+#include "color.h"
 #include "propername.h"
+#include "xalloc.h"
 #include "gettext.h"
 
 #define _(str) gettext (str)
@@ -56,23 +56,24 @@ static int force_po;
 /* Bit mask of subsets to remove.  */
 enum
 {
-  REMOVE_UNTRANSLATED	= 1 << 0,
-  REMOVE_TRANSLATED	= 1 << 1,
-  REMOVE_FUZZY		= 1 << 2,
-  REMOVE_NONFUZZY	= 1 << 3,
-  REMOVE_OBSOLETE	= 1 << 4,
-  REMOVE_NONOBSOLETE	= 1 << 5
+  REMOVE_UNTRANSLATED   = 1 << 0,
+  REMOVE_TRANSLATED     = 1 << 1,
+  REMOVE_FUZZY          = 1 << 2,
+  REMOVE_NONFUZZY       = 1 << 3,
+  REMOVE_OBSOLETE       = 1 << 4,
+  REMOVE_NONOBSOLETE    = 1 << 5
 };
 static int to_remove;
 
 /* Bit mask of actions to perform on all messages.  */
 enum
 {
-  SET_FUZZY		= 1 << 0,
-  RESET_FUZZY		= 1 << 1,
-  SET_OBSOLETE		= 1 << 2,
-  RESET_OBSOLETE	= 1 << 3,
-  REMOVE_PREV		= 1 << 4
+  SET_FUZZY             = 1 << 0,
+  RESET_FUZZY           = 1 << 1,
+  SET_OBSOLETE          = 1 << 2,
+  RESET_OBSOLETE        = 1 << 3,
+  REMOVE_PREV           = 1 << 4,
+  ADD_PREV              = 1 << 5
 };
 static int to_change;
 
@@ -83,6 +84,7 @@ static const struct option long_options[] =
   { "clear-fuzzy", no_argument, NULL, CHAR_MAX + 8 },
   { "clear-obsolete", no_argument, NULL, CHAR_MAX + 10 },
   { "clear-previous", no_argument, NULL, CHAR_MAX + 18 },
+  { "color", optional_argument, NULL, CHAR_MAX + 19 },
   { "directory", required_argument, NULL, 'D' },
   { "escape", no_argument, NULL, 'E' },
   { "force-po", no_argument, &force_po, 1 },
@@ -100,6 +102,7 @@ static const struct option long_options[] =
   { "only-fuzzy", no_argument, NULL, CHAR_MAX + 4 },
   { "only-obsolete", no_argument, NULL, CHAR_MAX + 6 },
   { "output-file", required_argument, NULL, 'o' },
+  { "previous", no_argument, NULL, CHAR_MAX + 21 },
   { "properties-input", no_argument, NULL, 'P' },
   { "properties-output", no_argument, NULL, 'p' },
   { "set-fuzzy", no_argument, NULL, CHAR_MAX + 7 },
@@ -109,6 +112,7 @@ static const struct option long_options[] =
   { "stringtable-input", no_argument, NULL, CHAR_MAX + 16 },
   { "stringtable-output", no_argument, NULL, CHAR_MAX + 17 },
   { "strict", no_argument, NULL, 'S' },
+  { "style", required_argument, NULL, CHAR_MAX + 20 },
   { "translated", no_argument, NULL, CHAR_MAX + 1 },
   { "untranslated", no_argument, NULL, CHAR_MAX + 2 },
   { "version", no_argument, NULL, 'V' },
@@ -120,12 +124,12 @@ static const struct option long_options[] =
 /* Forward declaration of local functions.  */
 static void usage (int status)
 #if defined __GNUC__ && ((__GNUC__ == 2 && __GNUC_MINOR__ >= 5) || __GNUC__ > 2)
-	__attribute__ ((noreturn))
+        __attribute__ ((noreturn))
 #endif
 ;
 static msgdomain_list_ty *process_msgdomain_list (msgdomain_list_ty *mdlp,
-						  msgdomain_list_ty *only_mdlp,
-						msgdomain_list_ty *ignore_mdlp);
+                                                  msgdomain_list_ty *only_mdlp,
+                                                msgdomain_list_ty *ignore_mdlp);
 
 
 int
@@ -172,151 +176,164 @@ main (int argc, char **argv)
   ignore_file = NULL;
 
   while ((optchar = getopt_long (argc, argv, "D:eEFhino:pPsVw:", long_options,
-				 NULL)) != EOF)
+                                 NULL)) != EOF)
     switch (optchar)
       {
-      case '\0':		/* Long option.  */
-	break;
+      case '\0':                /* Long option.  */
+        break;
 
       case 'D':
-	dir_list_append (optarg);
-	break;
+        dir_list_append (optarg);
+        break;
 
       case 'e':
-	message_print_style_escape (false);
-	break;
+        message_print_style_escape (false);
+        break;
 
       case 'E':
-	message_print_style_escape (true);
-	break;
+        message_print_style_escape (true);
+        break;
 
       case 'F':
-	sort_by_filepos = true;
-	break;
+        sort_by_filepos = true;
+        break;
 
       case 'h':
-	do_help = true;
-	break;
+        do_help = true;
+        break;
 
       case 'i':
-	message_print_style_indent ();
-	break;
+        message_print_style_indent ();
+        break;
 
       case 'n':
-	line_comment = 1;
-	break;
+        line_comment = 1;
+        break;
 
       case 'o':
-	output_file = optarg;
-	break;
+        output_file = optarg;
+        break;
 
       case 'p':
-	output_syntax = &output_format_properties;
-	break;
+        output_syntax = &output_format_properties;
+        break;
 
       case 'P':
-	input_syntax = &input_format_properties;
-	break;
+        input_syntax = &input_format_properties;
+        break;
 
       case 's':
-	sort_by_msgid = true;
-	break;
+        sort_by_msgid = true;
+        break;
 
       case 'S':
-	message_print_style_uniforum ();
-	break;
+        message_print_style_uniforum ();
+        break;
 
       case 'V':
-	do_version = true;
-	break;
+        do_version = true;
+        break;
 
       case 'w':
-	{
-	  int value;
-	  char *endp;
-	  value = strtol (optarg, &endp, 10);
-	  if (endp != optarg)
-	    message_page_width_set (value);
-	}
-	break;
+        {
+          int value;
+          char *endp;
+          value = strtol (optarg, &endp, 10);
+          if (endp != optarg)
+            message_page_width_set (value);
+        }
+        break;
 
       case CHAR_MAX + 1: /* --translated */
-	to_remove |= REMOVE_UNTRANSLATED;
-	break;
+        to_remove |= REMOVE_UNTRANSLATED;
+        break;
 
       case CHAR_MAX + 2: /* --untranslated */
-	to_remove |= REMOVE_TRANSLATED;
-	break;
+        to_remove |= REMOVE_TRANSLATED;
+        break;
 
       case CHAR_MAX + 3: /* --no-fuzzy */
-	to_remove |= REMOVE_FUZZY;
-	break;
+        to_remove |= REMOVE_FUZZY;
+        break;
 
       case CHAR_MAX + 4: /* --only-fuzzy */
-	to_remove |= REMOVE_NONFUZZY;
-	break;
+        to_remove |= REMOVE_NONFUZZY;
+        break;
 
       case CHAR_MAX + 5: /* --no-obsolete */
-	to_remove |= REMOVE_OBSOLETE;
-	break;
+        to_remove |= REMOVE_OBSOLETE;
+        break;
 
       case CHAR_MAX + 6: /* --only-obsolete */
-	to_remove |= REMOVE_NONOBSOLETE;
-	break;
+        to_remove |= REMOVE_NONOBSOLETE;
+        break;
 
       case CHAR_MAX + 7: /* --set-fuzzy */
-	to_change |= SET_FUZZY;
-	break;
+        to_change |= SET_FUZZY;
+        break;
 
       case CHAR_MAX + 8: /* --clear-fuzzy */
-	to_change |= RESET_FUZZY;
-	break;
+        to_change |= RESET_FUZZY;
+        break;
 
       case CHAR_MAX + 9: /* --set-obsolete */
-	to_change |= SET_OBSOLETE;
-	break;
+        to_change |= SET_OBSOLETE;
+        break;
 
       case CHAR_MAX + 10: /* --clear-obsolete */
-	to_change |= RESET_OBSOLETE;
-	break;
+        to_change |= RESET_OBSOLETE;
+        break;
 
       case CHAR_MAX + 11: /* --fuzzy */
-	to_remove |= REMOVE_NONFUZZY;
-	to_change |= RESET_FUZZY;
-	break;
+        to_remove |= REMOVE_NONFUZZY;
+        to_change |= RESET_FUZZY;
+        break;
 
       case CHAR_MAX + 12: /* --obsolete */
-	to_remove |= REMOVE_NONOBSOLETE;
-	to_change |= RESET_OBSOLETE;
-	break;
+        to_remove |= REMOVE_NONOBSOLETE;
+        to_change |= RESET_OBSOLETE;
+        break;
 
       case CHAR_MAX + 13: /* --no-wrap */
-	message_page_width_ignore ();
-	break;
+        message_page_width_ignore ();
+        break;
 
       case CHAR_MAX + 14: /* --only-file */
-	only_file = optarg;
-	break;
+        only_file = optarg;
+        break;
 
       case CHAR_MAX + 15: /* --ignore-file */
-	ignore_file = optarg;
-	break;
+        ignore_file = optarg;
+        break;
 
       case CHAR_MAX + 16: /* --stringtable-input */
-	input_syntax = &input_format_stringtable;
-	break;
+        input_syntax = &input_format_stringtable;
+        break;
 
       case CHAR_MAX + 17: /* --stringtable-output */
-	output_syntax = &output_format_stringtable;
-	break;
+        output_syntax = &output_format_stringtable;
+        break;
 
       case CHAR_MAX + 18: /* --clear-previous */
-	to_change |= REMOVE_PREV;
-	break;
+        to_change |= REMOVE_PREV;
+        break;
+
+      case CHAR_MAX + 19: /* --color */
+        if (handle_color_option (optarg) || color_test_mode)
+          usage (EXIT_FAILURE);
+        break;
+
+      case CHAR_MAX + 20: /* --style */
+        handle_style_option (optarg);
+        break;
+
+      case CHAR_MAX + 21: /* --previous */
+        to_change |= ADD_PREV;
+        break;
 
       default:
-	usage (EXIT_FAILURE);
-	/* NOTREACHED */
+        usage (EXIT_FAILURE);
+        /* NOTREACHED */
       }
 
   /* Version information requested.  */
@@ -325,10 +342,11 @@ main (int argc, char **argv)
       printf ("%s (GNU %s) %s\n", basename (program_name), PACKAGE, VERSION);
       /* xgettext: no-wrap */
       printf (_("Copyright (C) %s Free Software Foundation, Inc.\n\
-This is free software; see the source for copying conditions.  There is NO\n\
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+This is free software: you are free to change and redistribute it.\n\
+There is NO WARRANTY, to the extent permitted by law.\n\
 "),
-	      "2001-2006");
+              "2001-2010");
       printf (_("Written by %s.\n"), proper_name ("Bruno Haible"));
       exit (EXIT_SUCCESS);
     }
@@ -351,22 +369,22 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
   /* Verify selected options.  */
   if (!line_comment && sort_by_filepos)
     error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
-	   "--no-location", "--sort-by-file");
+           "--no-location", "--sort-by-file");
 
   if (sort_by_msgid && sort_by_filepos)
     error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
-	   "--sort-output", "--sort-by-file");
+           "--sort-output", "--sort-by-file");
 
   /* Read input file.  */
   result = read_catalog_file (input_file, input_syntax);
 
   /* Read optional files that limit the extent of the attribute changes.  */
   only_mdlp = (only_file != NULL
-	       ? read_catalog_file (only_file, input_syntax)
-	       : NULL);
+               ? read_catalog_file (only_file, input_syntax)
+               : NULL);
   ignore_mdlp = (ignore_file != NULL
-		 ? read_catalog_file (ignore_file, input_syntax)
-		 : NULL);
+                 ? read_catalog_file (ignore_file, input_syntax)
+                 : NULL);
 
   /* Filter the messages and manipulate the attributes.  */
   result = process_msgdomain_list (result, only_mdlp, ignore_mdlp);
@@ -389,8 +407,8 @@ static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-	     program_name);
+    fprintf (stderr, _("Try '%s --help' for more information.\n"),
+             program_name);
   else
     {
       printf (_("\
@@ -448,6 +466,9 @@ Attribute manipulation:\n"));
       printf (_("\
       --clear-obsolete        set all messages non-obsolete\n"));
       printf (_("\
+      --previous              when setting 'fuzzy', keep previous msgids\n\
+                              of translated messages.\n"));
+      printf (_("\
       --clear-previous        remove the \"previous msgid\" from all messages\n"));
       printf (_("\
       --only-file=FILE.po     manipulate only entries listed in FILE.po\n"));
@@ -468,6 +489,12 @@ Input file syntax:\n"));
       printf (_("\
 Output details:\n"));
       printf (_("\
+      --color                 use colors and other text attributes always\n\
+      --color=WHEN            use colors and other text attributes if WHEN.\n\
+                              WHEN may be 'always', 'never', 'auto', or 'html'.\n"));
+      printf (_("\
+      --style=STYLEFILE       specify CSS style rule file for --color\n"));
+      printf (_("\
   -e, --no-escape             do not use C escapes in output (default)\n"));
       printf (_("\
   -E, --escape                use C escapes in output, no extended chars\n"));
@@ -502,8 +529,12 @@ Informative output:\n"));
       printf (_("\
   -V, --version               output version information and exit\n"));
       printf ("\n");
+      /* TRANSLATORS: The placeholder indicates the bug-reporting address
+         for this package.  Please add _another line_ saying
+         "Report translation bugs to <...>\n" with the address for translation
+         bugs (typically your translation team's web or email address).  */
       fputs (_("Report bugs to <bug-gnu-gettext@gnu.org>.\n"),
-	     stdout);
+             stdout);
     }
 
   exit (status);
@@ -520,20 +551,20 @@ is_message_selected (const message_ty *mp)
 
   if ((to_remove & (REMOVE_UNTRANSLATED | REMOVE_TRANSLATED))
       && (mp->msgstr[0] == '\0'
-	  ? to_remove & REMOVE_UNTRANSLATED
-	  : to_remove & REMOVE_TRANSLATED))
+          ? to_remove & REMOVE_UNTRANSLATED
+          : to_remove & REMOVE_TRANSLATED))
     return false;
 
   if ((to_remove & (REMOVE_FUZZY | REMOVE_NONFUZZY))
       && (mp->is_fuzzy
-	  ? to_remove & REMOVE_FUZZY
-	  : to_remove & REMOVE_NONFUZZY))
+          ? to_remove & REMOVE_FUZZY
+          : to_remove & REMOVE_NONFUZZY))
     return false;
 
   if ((to_remove & (REMOVE_OBSOLETE | REMOVE_NONOBSOLETE))
       && (mp->obsolete
-	  ? to_remove & REMOVE_OBSOLETE
-	  : to_remove & REMOVE_NONOBSOLETE))
+          ? to_remove & REMOVE_OBSOLETE
+          : to_remove & REMOVE_NONOBSOLETE))
     return false;
 
   return true;
@@ -542,7 +573,7 @@ is_message_selected (const message_ty *mp)
 
 static void
 process_message_list (message_list_ty *mlp,
-		      message_list_ty *only_mlp, message_list_ty *ignore_mlp)
+                      message_list_ty *only_mlp, message_list_ty *ignore_mlp)
 {
   /* Keep only the selected messages.  */
   message_list_remove_if_not (mlp, is_message_selected);
@@ -553,58 +584,73 @@ process_message_list (message_list_ty *mlp,
       size_t j;
 
       for (j = 0; j < mlp->nitems; j++)
-	{
-	  message_ty *mp = mlp->item[j];
+        {
+          message_ty *mp = mlp->item[j];
 
-	  /* Attribute changes only affect messages listed in --only-file
-	     and not listed in --ignore-file.  */
-	  if ((only_mlp
-	       ? message_list_search (only_mlp, mp->msgctxt, mp->msgid) != NULL
-	       : true)
-	      && (ignore_mlp
-		  ? message_list_search (ignore_mlp, mp->msgctxt, mp->msgid) == NULL
-		  : true))
-	    {
-	      if (to_change & SET_FUZZY)
-		mp->is_fuzzy = true;
-	      if (to_change & RESET_FUZZY)
-		mp->is_fuzzy = false;
-	      /* Always keep the header entry non-obsolete.  */
-	      if ((to_change & SET_OBSOLETE) && !is_header (mp))
-		mp->obsolete = true;
-	      if (to_change & RESET_OBSOLETE)
-		mp->obsolete = false;
-	      if (to_change & REMOVE_PREV)
-		{
-		  mp->prev_msgctxt = NULL;
-		  mp->prev_msgid = NULL;
-		  mp->prev_msgid_plural = NULL;
-		}
-	    }
-	}
+          /* Attribute changes only affect messages listed in --only-file
+             and not listed in --ignore-file.  */
+          if ((only_mlp
+               ? message_list_search (only_mlp, mp->msgctxt, mp->msgid) != NULL
+               : true)
+              && (ignore_mlp
+                  ? message_list_search (ignore_mlp, mp->msgctxt, mp->msgid) == NULL
+                  : true))
+            {
+              if (to_change & SET_FUZZY)
+                {
+                  if ((to_change & ADD_PREV) && !is_header (mp)
+                      && !mp->is_fuzzy && mp->msgstr[0] != '\0')
+                    {
+                      mp->prev_msgctxt =
+                        (mp->msgctxt != NULL ? xstrdup (mp->msgctxt) : NULL);
+                      mp->prev_msgid =
+                        (mp->msgid != NULL ? xstrdup (mp->msgid) : NULL);
+                      mp->prev_msgid_plural =
+                        (mp->msgid_plural != NULL
+                         ? xstrdup (mp->msgid_plural)
+                         : NULL);
+                    }
+                  mp->is_fuzzy = true;
+                }
+
+              if (to_change & RESET_FUZZY)
+                mp->is_fuzzy = false;
+              /* Always keep the header entry non-obsolete.  */
+              if ((to_change & SET_OBSOLETE) && !is_header (mp))
+                mp->obsolete = true;
+              if (to_change & RESET_OBSOLETE)
+                mp->obsolete = false;
+              if (to_change & REMOVE_PREV)
+                {
+                  mp->prev_msgctxt = NULL;
+                  mp->prev_msgid = NULL;
+                  mp->prev_msgid_plural = NULL;
+                }
+            }
+        }
     }
 }
 
 
 static msgdomain_list_ty *
 process_msgdomain_list (msgdomain_list_ty *mdlp,
-			msgdomain_list_ty *only_mdlp,
-			msgdomain_list_ty *ignore_mdlp)
+                        msgdomain_list_ty *only_mdlp,
+                        msgdomain_list_ty *ignore_mdlp)
 {
   size_t k;
 
   for (k = 0; k < mdlp->nitems; k++)
     process_message_list (mdlp->item[k]->messages,
-			  only_mdlp
-			  ? msgdomain_list_sublist (only_mdlp,
-						    mdlp->item[k]->domain,
-						    true)
-			  : NULL,
-			  ignore_mdlp
-			  ? msgdomain_list_sublist (ignore_mdlp,
-						    mdlp->item[k]->domain,
-						    false)
-			  : NULL);
+                          only_mdlp
+                          ? msgdomain_list_sublist (only_mdlp,
+                                                    mdlp->item[k]->domain,
+                                                    true)
+                          : NULL,
+                          ignore_mdlp
+                          ? msgdomain_list_sublist (ignore_mdlp,
+                                                    mdlp->item[k]->domain,
+                                                    false)
+                          : NULL);
 
   return mdlp;
 }
