@@ -30,9 +30,11 @@ VARIABLE(formatstring_elisp)
 VARIABLE(formatstring_gcc_internal)
 VARIABLE(formatstring_gfc_internal)
 VARIABLE(formatstring_java)
+VARIABLE(formatstring_javascript)
 VARIABLE(formatstring_kde)
 VARIABLE(formatstring_librep)
 VARIABLE(formatstring_lisp)
+VARIABLE(formatstring_lua)
 VARIABLE(formatstring_objc)
 VARIABLE(formatstring_parsers)
 VARIABLE(formatstring_pascal)
@@ -40,6 +42,7 @@ VARIABLE(formatstring_perl)
 VARIABLE(formatstring_perl_brace)
 VARIABLE(formatstring_php)
 VARIABLE(formatstring_python)
+VARIABLE(formatstring_python_brace)
 VARIABLE(formatstring_qt)
 VARIABLE(formatstring_qt_plural)
 VARIABLE(formatstring_scheme)
